import type { ReactNode } from "react"
import Script from "next/script"
import { orbitron, playfair, montserrat, cormorant } from "./fonts"
import "./globals.css"
import { ContentProvider } from "../components/content-provider"

export const metadata = {
  title: "The One Token",
  description: "The revolutionary crypto project leading the transition from Web3 to Web4",
  icons: {
    icon: [
      { url: "/favicon.ico", sizes: "32x32", type: "image/x-icon" },
      { url: "/favicon.svg", type: "image/svg+xml" },
    ],
    apple: { url: "/favicon.svg", type: "image/svg+xml" },
  },
    generator: 'v0.dev'
}

export default function RootLayout({ children }: { children: ReactNode }) {
  return (
    <html
      lang="en"
      className={`${orbitron.variable} ${playfair.variable} ${montserrat.variable} ${cormorant.variable}`}
    >
      <head>
        <Script id="google-tag-manager" strategy="afterInteractive">
          {`
          (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
          new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
          j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
          'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
          })(window,document,'script','dataLayer','GTM-P6Z27P6Q');
        `}
        </Script>

        {/* PlayAI Chat Agent */}
        <Script src="https://unpkg.com/@play-ai/agent-web-sdk" strategy="afterInteractive" />
        <Script id="playai-chat-agent" strategy="afterInteractive">
          {`
          addEventListener("load", () => {
            if (typeof PlayAI !== 'undefined') {
              PlayAI.open('VzYAsNq74e94WL6_ALjwq');
            }
          });
        `}
        </Script>
      </head>
      <body className="text-white font-montserrat">
        <noscript>
          <iframe
            src="https://www.googletagmanager.com/ns.html?id=GTM-P6Z27P6Q"
            height="0"
            width="0"
            style={{ display: "none", visibility: "hidden" }}
          ></iframe>
        </noscript>
        <ContentProvider>{children}</ContentProvider>
      </body>
    </html>
  )
}



import './globals.css'